pub struct ImguiTextureFeedbackQueue { /* private fields */ }Expand description
Main-world queue of managed texture feedback produced by the render world.
Implementations
Sourceimpl ImguiTextureFeedbackQueue
impl ImguiTextureFeedbackQueue
Sourcepub fn push(&self, feedback: TextureFeedback)
pub fn push(&self, feedback: TextureFeedback)
Queue one managed texture feedback item to be applied before the next frame begins.
Sourcepub fn last_applied(&self) -> usize
pub fn last_applied(&self) -> usize
Number of texture entries updated by the most recent drain/apply pass.